@@ -23,6 +23,7 @@ mod rebase;
 pub mod remotes;
 mod repository;
 mod reset;
+mod reword;
 mod staging;
 mod stash;
 mod state;
@@ -34,12 +35,13 @@ pub mod utils;
 
 pub use blame::{blame_file, BlameHunk, FileBlame};
 pub use branch::{
-	branch_compare_upstream, checkout_branch, config_is_pull_rebase,
-	create_branch, delete_branch, get_branch_remote,
-	get_branches_info, merge_commit::merge_upstream_commit,
+	branch_compare_upstream, checkout_branch, checkout_commit,
+	config_is_pull_rebase, create_branch, delete_branch,
+	get_branch_remote, get_branches_info,
+	merge_commit::merge_upstream_commit,
 	merge_ff::branch_merge_upstream_fastforward,
 	merge_rebase::merge_upstream_rebase, rename::rename_branch,
-	validate_branch_name, BranchCompare, BranchInfo,
+	validate_branch_name, BranchCompare, BranchDetails, BranchInfo,
 };
 pub use commit::{amend, commit, tag_commit};
 pub use commit_details::{
@@ -74,7 +76,8 @@ pub use remotes::{
 };
 pub(crate) use repository::repo;
 pub use repository::{RepoPath, RepoPathRef};
-pub use reset::{reset_stage, reset_workdir};
+pub use reset::{reset_repo, reset_stage, reset_workdir};
+pub use reword::reword;
 pub use staging::{discard_lines, stage_lines};
 pub use stash::{
 	get_stashes, stash_apply, stash_drop, stash_pop, stash_save,
@@ -95,6 +98,8 @@ pub use utils::{
 	stage_add_file, stage_addremoved, Head,
 };
 
+pub use git2::ResetType;
+
 #[cfg(test)]
 mod tests {
 	use super::{
