@@ -2,7 +2,7 @@ use crate::{
 	accessors,
 	cmdbar::CommandBar,
 	components::{
-		event_pump, AppOption, BlameFileComponent,
+		event_pump, AppOption, BlameFileComponent, BranchFindPopup,
 		BranchListComponent, CommandBlocking, CommandInfo,
 		CommitComponent, CompareCommitsComponent, Component,
 		ConfirmComponent, CreateBranchComponent, DrawableComponent,
@@ -10,7 +10,7 @@ use crate::{
 		FileRevlogComponent, HelpComponent, InspectCommitComponent,
 		MsgComponent, OptionsPopupComponent, PullComponent,
 		PushComponent, PushTagsComponent, RenameBranchComponent,
-		RevisionFilesPopup, StashMsgComponent,
+		ResetPopupComponent, RevisionFilesPopup, StashMsgComponent,
 		SubmodulesListComponent, TagCommitComponent,
 		TagListComponent,
 	},
@@ -34,20 +34,20 @@ use asyncgit::{
 };
 use crossbeam_channel::Sender;
 use crossterm::event::{Event, KeyEvent};
-use std::{
-	cell::{Cell, RefCell},
-	path::Path,
-	rc::Rc,
-};
-use tui::{
+use ratatui::{
 	backend::Backend,
 	layout::{
 		Alignment, Constraint, Direction, Layout, Margin, Rect,
 	},
-	text::{Span, Spans},
+	text::{Line, Span},
 	widgets::{Block, Borders, Paragraph, Tabs},
 	Frame,
 };
+use std::{
+	cell::{Cell, RefCell},
+	path::Path,
+	rc::Rc,
+};
 use unicode_width::UnicodeWidthStr;
 
 #[derive(Clone)]
@@ -73,6 +73,7 @@ pub struct App {
 	external_editor_popup: ExternalEditorComponent,
 	revision_files_popup: RevisionFilesPopup,
 	find_file_popup: FileFindPopup,
+	branch_find_popup: BranchFindPopup,
 	push_popup: PushComponent,
 	push_tags_popup: PushTagsComponent,
 	pull_popup: PullComponent,
@@ -84,6 +85,7 @@ pub struct App {
 	options_popup: OptionsPopupComponent,
 	submodule_popup: SubmodulesListComponent,
 	tags_popup: TagListComponent,
+	reset_popup: ResetPopupComponent,
 	cmdbar: RefCell<CommandBar>,
 	tab: usize,
 	revlog: Revlog,
@@ -178,6 +180,7 @@ impl App {
 				sender,
 				theme.clone(),
 				key_config.clone(),
+				options.clone(),
 			),
 			compare_commits_popup: CompareCommitsComponent::new(
 				&repo,
@@ -185,6 +188,7 @@ impl App {
 				sender,
 				theme.clone(),
 				key_config.clone(),
+				options.clone(),
 			),
 			external_editor_popup: ExternalEditorComponent::new(
 				theme.clone(),
@@ -204,6 +208,12 @@ impl App {
 				theme.clone(),
 				key_config.clone(),
 			),
+			reset_popup: ResetPopupComponent::new(
+				&queue,
+				&repo,
+				theme.clone(),
+				key_config.clone(),
+			),
 			pull_popup: PullComponent::new(
 				&repo,
 				&queue,
@@ -266,6 +276,11 @@ impl App {
 				theme.clone(),
 				key_config.clone(),
 			),
+			branch_find_popup: BranchFindPopup::new(
+				&queue,
+				theme.clone(),
+				key_config.clone(),
+			),
 			do_quit: QuitState::None,
 			cmdbar: RefCell::new(CommandBar::new(
 				theme.clone(),
@@ -445,16 +460,18 @@ impl App {
 			self.process_queue(flags)?;
 		} else if let InputEvent::State(polling_state) = ev {
 			self.external_editor_popup.hide();
-			if let InputState::Paused = polling_state {
-				let result = match self.file_to_open.take() {
-					Some(path) => {
+			if matches!(polling_state, InputState::Paused) {
+				let result =
+					if let Some(path) = self.file_to_open.take() {
 						ExternalEditorComponent::open_file_in_editor(
 							&self.repo.borrow(),
 							Path::new(&path),
 						)
-					}
-					None => self.commit.show_editor(),
-				};
+					} else {
+						let changes =
+							self.status_tab.get_files_changes()?;
+						self.commit.show_editor(changes)
+					};
 
 				if let Err(e) = result {
 					let msg =
@@ -482,6 +499,7 @@ impl App {
 		self.files_tab.update()?;
 		self.stashing_tab.update()?;
 		self.stashlist_tab.update()?;
+		self.reset_popup.update()?;
 
 		self.update_commands();
 
@@ -568,6 +586,7 @@ impl App {
 		self,
 		[
 			find_file_popup,
+			branch_find_popup,
 			msg,
 			reset,
 			commit,
@@ -588,6 +607,7 @@ impl App {
 			revision_files_popup,
 			submodule_popup,
 			tags_popup,
+			reset_popup,
 			options_popup,
 			help,
 			revlog,
@@ -613,10 +633,12 @@ impl App {
 			select_branch_popup,
 			submodule_popup,
 			tags_popup,
+			reset_popup,
 			create_branch_popup,
 			rename_branch_popup,
 			revision_files_popup,
 			find_file_popup,
+			branch_find_popup,
 			push_popup,
 			push_tags_popup,
 			pull_popup,
@@ -803,6 +825,9 @@ impl App {
 			}
 			InternalEvent::Update(u) => flags.insert(u),
 			InternalEvent::OpenCommit => self.commit.show()?,
+			InternalEvent::RewordCommit(id) => {
+				self.commit.open(Some(id))?;
+			}
 			InternalEvent::PopupStashing(opts) => {
 				self.stashmsg_popup.options(opts);
 				self.stashmsg_popup.show()?;
@@ -877,6 +902,11 @@ impl App {
 				flags
 					.insert(NeedsUpdate::ALL | NeedsUpdate::COMMANDS);
 			}
+			InternalEvent::OpenBranchFinder(branches) => {
+				self.branch_find_popup.open(branches)?;
+				flags
+					.insert(NeedsUpdate::ALL | NeedsUpdate::COMMANDS);
+			}
 			InternalEvent::OptionSwitched(o) => {
 				match o {
 					AppOption::StatusShowUntracked => {
@@ -897,6 +927,11 @@ impl App {
 				flags
 					.insert(NeedsUpdate::ALL | NeedsUpdate::COMMANDS);
 			}
+			InternalEvent::BranchFinderChanged(idx) => {
+				self.select_branch_popup.branch_finder_update(idx)?;
+				flags
+					.insert(NeedsUpdate::ALL | NeedsUpdate::COMMANDS);
+			}
 			InternalEvent::OpenPopup(popup) => {
 				self.open_popup(popup)?;
 				flags
@@ -924,6 +959,9 @@ impl App {
 				self.do_quit =
 					QuitState::OpenSubmodule(submodule_repo_path);
 			}
+			InternalEvent::OpenResetPopup(id) => {
+				self.reset_popup.open(id)?;
+			}
 		};
 
 		Ok(flags)
@@ -983,8 +1021,7 @@ impl App {
 					branch_ref.rsplit('/').next().map_or_else(
 						|| {
 							InternalEvent::ShowErrorMsg(format!(
-						"Failed to find the branch name in {}",
-						branch_ref
+						"Failed to find the branch name in {branch_ref}"
 					))
 						},
 						|name| {
@@ -1154,7 +1191,7 @@ impl App {
 		let table_area = r; // use entire area to allow drawing the horizontal separator line
 		let text_area = left_right[1];
 
-		let tabs = tab_labels.into_iter().map(Spans::from).collect();
+		let tabs = tab_labels.into_iter().map(Line::from).collect();
 
 		f.render_widget(
 			Tabs::new(tabs)
@@ -1171,7 +1208,7 @@ impl App {
 		);
 
 		f.render_widget(
-			Paragraph::new(Spans::from(vec![Span::styled(
+			Paragraph::new(Line::from(vec![Span::styled(
 				ellipsis_trim_start(
 					&self.repo_path_text,
 					text_area.width as usize,
