@@ -2,8 +2,8 @@ use crate::bug_report;
 use anyhow::{anyhow, Result};
 use asyncgit::sync::RepoPath;
 use clap::{
-	crate_authors, crate_description, crate_name, crate_version,
-	value_parser, Arg, Command as ClapApp,
+	crate_authors, crate_description, crate_name, crate_version, Arg,
+	Command as ClapApp,
 };
 use simplelog::{Config, LevelFilter, WriteLogger};
 use std::{
@@ -15,18 +15,19 @@ use std::{
 pub struct CliArgs {
 	pub theme: PathBuf,
 	pub repo_path: RepoPath,
-	pub poll_watcher: bool,
+	pub notify_watcher: bool,
 }
 
 pub fn process_cmdline() -> Result<CliArgs> {
 	let app = app();
 
 	let arg_matches = app.get_matches();
-	if arg_matches.contains_id("bugreport") {
+
+	if arg_matches.get_flag("bugreport") {
 		bug_report::generate_bugreport();
 		std::process::exit(0);
 	}
-	if arg_matches.contains_id("logging") {
+	if arg_matches.get_flag("logging") {
 		setup_logging()?;
 	}
 
@@ -53,13 +54,13 @@ pub fn process_cmdline() -> Result<CliArgs> {
 		get_app_config_path()?.join("theme.ron")
 	};
 
-	let arg_poll: bool =
-		*arg_matches.get_one("poll").unwrap_or(&false);
+	let notify_watcher: bool =
+		*arg_matches.get_one("watcher").unwrap_or(&false);
 
 	Ok(CliArgs {
 		theme,
-		poll_watcher: arg_poll,
 		repo_path,
+		notify_watcher,
 	})
 }
 
@@ -95,16 +96,16 @@ fn app() -> ClapApp {
 				.num_args(0),
 		)
 		.arg(
-			Arg::new("poll")
-				.help("Poll folder for changes instead of using file system events. This can be useful if you run into issues with maximum # of file descriptors")
-				.long("polling")
-				.num_args(0)
-				.value_parser(value_parser!(bool)),
+			Arg::new("watcher")
+				.help("Use notify-based file system watcher instead of tick-based update. This is more performant, but can cause issues on some platforms. See https://github.com/extrawurst/gitui/blob/master/FAQ.md#watcher for details.")
+				.long("watcher")
+				.action(clap::ArgAction::SetTrue),
 		)
 		.arg(
 			Arg::new("bugreport")
 				.help("Generate a bug report")
-				.long("bugreport"),
+				.long("bugreport")
+				.action(clap::ArgAction::SetTrue),
 		)
 		.arg(
 			Arg::new("directory")
@@ -128,11 +129,13 @@ fn setup_logging() -> Result<()> {
 	let mut path = get_app_cache_path()?;
 	path.push("gitui.log");
 
-	let _ = WriteLogger::init(
+	println!("Logging enabled. log written to: {path:?}");
+
+	WriteLogger::init(
 		LevelFilter::Trace,
 		Config::default(),
 		File::create(path)?,
-	);
+	)?;
 
 	Ok(())
 }
