@@ -7,30 +7,35 @@ use crate::{
 	keys::{key_match, SharedKeyConfig},
 	queue::{InternalEvent, Queue},
 	strings::{self, symbol},
+	try_or_popup,
 	ui::style::{SharedTheme, Theme},
-	ui::{calc_scroll_top, draw_scrollbar},
+	ui::{calc_scroll_top, draw_scrollbar, Orientation},
 };
 use anyhow::Result;
-use asyncgit::sync::{BranchInfo, CommitId, Tags};
+use asyncgit::sync::{
+	checkout_commit, BranchDetails, BranchInfo, CommitId,
+	RepoPathRef, Tags,
+};
 use chrono::{DateTime, Local};
 use crossterm::event::Event;
 use itertools::Itertools;
+use ratatui::{
+	backend::Backend,
+	layout::{Alignment, Rect},
+	text::{Line, Span},
+	widgets::{Block, Borders, Paragraph},
+	Frame,
+};
 use std::{
 	borrow::Cow, cell::Cell, cmp, collections::BTreeMap,
 	convert::TryFrom, time::Instant,
 };
-use tui::{
-	backend::Backend,
-	layout::{Alignment, Rect},
-	text::{Span, Spans},
-	widgets::{Block, Borders, Paragraph},
-	Frame,
-};
 
 const ELEMENTS_PER_LINE: usize = 9;
 
 ///
 pub struct CommitList {
+	repo: RepoPathRef,
 	title: Box<str>,
 	selection: usize,
 	count_total: usize,
@@ -38,8 +43,9 @@ pub struct CommitList {
 	marked: Vec<(usize, CommitId)>,
 	scroll_state: (Instant, f32),
 	tags: Option<Tags>,
-	branches: BTreeMap<CommitId, Vec<String>>,
-	current_size: Cell<(u16, u16)>,
+	local_branches: BTreeMap<CommitId, Vec<BranchInfo>>,
+	remote_branches: BTreeMap<CommitId, Vec<BranchInfo>>,
+	current_size: Cell<Option<(u16, u16)>>,
 	scroll_top: Cell<usize>,
 	theme: SharedTheme,
 	queue: Queue,
@@ -49,20 +55,23 @@ pub struct CommitList {
 impl CommitList {
 	///
 	pub fn new(
+		repo: RepoPathRef,
 		title: &str,
 		theme: SharedTheme,
 		queue: Queue,
 		key_config: SharedKeyConfig,
 	) -> Self {
 		Self {
+			repo,
 			items: ItemBatch::default(),
 			marked: Vec::with_capacity(2),
 			selection: 0,
 			count_total: 0,
 			scroll_state: (Instant::now(), 0_f32),
 			tags: None,
-			branches: BTreeMap::default(),
-			current_size: Cell::new((0, 0)),
+			local_branches: BTreeMap::default(),
+			remote_branches: BTreeMap::default(),
+			current_size: Cell::new(None),
 			scroll_top: Cell::new(0),
 			theme,
 			queue,
@@ -81,8 +90,8 @@ impl CommitList {
 		self.selection
 	}
 
-	///
-	pub fn current_size(&self) -> (u16, u16) {
+	/// will return view size or None before the first render
+	pub fn current_size(&self) -> Option<(u16, u16)> {
 		self.current_size.get()
 	}
 
@@ -202,8 +211,10 @@ impl CommitList {
 		#[allow(clippy::cast_possible_truncation)]
 		let speed_int = usize::try_from(self.scroll_state.1 as i64)?.max(1);
 
-		let page_offset =
-			usize::from(self.current_size.get().1).saturating_sub(1);
+		let page_offset = usize::from(
+			self.current_size.get().unwrap_or_default().1,
+		)
+		.saturating_sub(1);
 
 		let new_selection = match scroll {
 			ScrollType::Up => {
@@ -289,12 +300,13 @@ impl CommitList {
 		e: &'a LogEntry,
 		selected: bool,
 		tags: Option<String>,
-		branches: Option<String>,
+		local_branches: Option<String>,
+		remote_branches: Option<String>,
 		theme: &Theme,
 		width: usize,
 		now: DateTime<Local>,
 		marked: Option<bool>,
-	) -> Spans<'a> {
+	) -> Line<'a> {
 		let mut txt: Vec<Span> = Vec::with_capacity(
 			ELEMENTS_PER_LINE + if marked.is_some() { 2 } else { 0 },
 		);
@@ -350,10 +362,18 @@ impl CommitList {
 			txt.push(Span::styled(tags, theme.tags(selected)));
 		}
 
-		if let Some(branches) = branches {
+		if let Some(local_branches) = local_branches {
 			txt.push(splitter.clone());
 			txt.push(Span::styled(
-				branches,
+				local_branches,
+				theme.branch(selected, true),
+			));
+		}
+
+		if let Some(remote_branches) = remote_branches {
+			txt.push(splitter.clone());
+			txt.push(Span::styled(
+				remote_branches,
 				theme.branch(selected, true),
 			));
 		}
@@ -370,13 +390,13 @@ impl CommitList {
 			theme.text(true, selected),
 		));
 
-		Spans::from(txt)
+		Line::from(txt)
 	}
 
-	fn get_text(&self, height: usize, width: usize) -> Vec<Spans> {
+	fn get_text(&self, height: usize, width: usize) -> Vec<Line> {
 		let selection = self.relative_selection();
 
-		let mut txt: Vec<Spans> = Vec::with_capacity(height);
+		let mut txt: Vec<Line> = Vec::with_capacity(height);
 
 		let now = Local::now();
 
@@ -398,12 +418,54 @@ impl CommitList {
 					},
 				);
 
-			let branches = self.branches.get(&e.id).map(|names| {
-				names
-					.iter()
-					.map(|name| format!("{{{name}}}"))
-					.join(" ")
-			});
+			let local_branches =
+				self.local_branches.get(&e.id).map(|local_branch| {
+					local_branch
+						.iter()
+						.map(|local_branch| {
+							format!("{{{0}}}", local_branch.name)
+						})
+						.join(" ")
+				});
+
+			let remote_branches = self
+				.remote_branches
+				.get(&e.id)
+				.and_then(|remote_branches| {
+					let filtered_branches: Vec<_> = remote_branches
+						.iter()
+						.filter(|remote_branch| {
+							self.local_branches
+								.get(&e.id)
+								.map_or(true, |local_branch| {
+									local_branch.iter().any(
+										|local_branch| {
+											let has_corresponding_local_branch = match &local_branch.details {
+												BranchDetails::Local(details) =>
+													details
+														.upstream
+														.as_ref()
+														.map_or(false, |upstream| upstream.reference == remote_branch.reference),
+												BranchDetails::Remote(_) =>
+														false,
+											};
+
+											!has_corresponding_local_branch
+										},
+									)
+								})
+						})
+						.map(|remote_branch| {
+							format!("[{0}]", remote_branch.name)
+						})
+						.collect();
+
+					if filtered_branches.is_empty() {
+						None
+					} else {
+						Some(filtered_branches.join(" "))
+					}
+				});
 
 			let marked = if any_marked {
 				self.is_marked(&e.id)
@@ -415,7 +477,8 @@ impl CommitList {
 				e,
 				idx + self.scroll_top.get() == selection,
 				tags,
-				branches,
+				local_branches,
+				remote_branches,
 				&self.theme,
 				width,
 				now,
@@ -435,14 +498,43 @@ impl CommitList {
 		self.selection = position;
 	}
 
-	pub fn set_branches(&mut self, branches: Vec<BranchInfo>) {
-		self.branches.clear();
+	pub fn checkout(&mut self) {
+		if let Some(commit_hash) =
+			self.selected_entry().map(|entry| entry.id)
+		{
+			try_or_popup!(
+				self,
+				"failed to checkout commit:",
+				checkout_commit(&self.repo.borrow(), commit_hash)
+			);
+		}
+	}
 
-		for b in branches {
-			self.branches
-				.entry(b.top_commit)
+	pub fn set_local_branches(
+		&mut self,
+		local_branches: Vec<BranchInfo>,
+	) {
+		self.local_branches.clear();
+
+		for local_branch in local_branches {
+			self.local_branches
+				.entry(local_branch.top_commit)
 				.or_default()
-				.push(b.name);
+				.push(local_branch);
+		}
+	}
+
+	pub fn set_remote_branches(
+		&mut self,
+		remote_branches: Vec<BranchInfo>,
+	) {
+		self.remote_branches.clear();
+
+		for remote_branch in remote_branches {
+			self.remote_branches
+				.entry(remote_branch.top_commit)
+				.or_default()
+				.push(remote_branch);
 		}
 	}
 }
@@ -457,9 +549,9 @@ impl DrawableComponent for CommitList {
 			area.width.saturating_sub(2),
 			area.height.saturating_sub(2),
 		);
-		self.current_size.set(current_size);
+		self.current_size.set(Some(current_size));
 
-		let height_in_lines = self.current_size.get().1 as usize;
+		let height_in_lines = current_size.1 as usize;
 		let selection = self.relative_selection();
 
 		self.scroll_top.set(calc_scroll_top(
@@ -501,6 +593,7 @@ impl DrawableComponent for CommitList {
 			&self.theme,
 			self.count_total,
 			self.selection,
+			Orientation::Vertical,
 		);
 
 		Ok(())
@@ -537,6 +630,12 @@ impl Component for CommitList {
 				) {
 					self.mark();
 					true
+				} else if key_match(
+					k,
+					self.key_config.keys.log_checkout_commit,
+				) {
+					self.checkout();
+					true
 				} else {
 					false
 				};
