@@ -1,23 +1,24 @@
 use super::{
 	command_pump, event_pump, visibility_blocking, CommandBlocking,
 	CommandInfo, CommitDetailsComponent, Component, DiffComponent,
-	DrawableComponent, EventState, FileTreeOpen,
+	DrawableComponent, EventState,
 };
 use crate::{
 	accessors,
 	keys::{key_match, SharedKeyConfig},
+	options::SharedOptions,
 	queue::{InternalEvent, Queue, StackablePopupOpen},
 	strings,
 	ui::style::SharedTheme,
 };
 use anyhow::Result;
 use asyncgit::{
-	sync::{diff::DiffOptions, CommitId, CommitTags, RepoPathRef},
+	sync::{CommitId, CommitTags, RepoPathRef},
 	AsyncDiff, AsyncGitNotification, DiffParams, DiffType,
 };
 use crossbeam_channel::Sender;
 use crossterm::event::Event;
-use tui::{
+use ratatui::{
 	backend::Backend,
 	layout::{Constraint, Direction, Layout, Rect},
 	widgets::Clear,
@@ -61,6 +62,7 @@ pub struct InspectCommitComponent {
 	git_diff: AsyncDiff,
 	visible: bool,
 	key_config: SharedKeyConfig,
+	options: SharedOptions,
 }
 
 impl DrawableComponent for InspectCommitComponent {
@@ -71,7 +73,7 @@ impl DrawableComponent for InspectCommitComponent {
 	) -> Result<()> {
 		if self.is_visible() {
 			let percentages = if self.diff.focused() {
-				(30, 70)
+				(0, 100)
 			} else {
 				(50, 50)
 			};
@@ -126,7 +128,7 @@ impl Component for InspectCommitComponent {
 			));
 
 			out.push(CommandInfo::new(
-				strings::commands::diff_focus_left(&self.key_config),
+				strings::commands::close_popup(&self.key_config),
 				true,
 				self.diff.focused() || force_all,
 			));
@@ -138,12 +140,6 @@ impl Component for InspectCommitComponent {
 				true,
 				true,
 			));
-
-			out.push(CommandInfo::new(
-				strings::commands::edit_item(&self.key_config),
-				true,
-				true,
-			));
 		}
 
 		visibility_blocking(self)
@@ -163,41 +159,21 @@ impl Component for InspectCommitComponent {
 
 			if let Event::Key(e) = ev {
 				if key_match(e, self.key_config.keys.exit_popup) {
-					self.hide_stacked(false);
+					if self.diff.focused() {
+						self.details.focus(true);
+						self.diff.focus(false);
+					} else {
+						self.hide_stacked(false);
+					}
 				} else if key_match(
 					e,
-					self.key_config.keys.focus_right,
+					self.key_config.keys.move_right,
 				) && self.can_focus_diff()
 				{
 					self.details.focus(false);
 					self.diff.focus(true);
-				} else if key_match(
-					e,
-					self.key_config.keys.focus_left,
-				) && self.diff.focused()
+				} else if key_match(e, self.key_config.keys.move_left)
 				{
-					self.details.focus(true);
-					self.diff.focus(false);
-				} else if key_match(
-					e,
-					self.key_config.keys.open_file_tree,
-				) {
-					if let Some(commit) = self
-						.open_request
-						.as_ref()
-						.map(|open| open.commit_id)
-					{
-						self.hide_stacked(true);
-						self.queue.push(InternalEvent::OpenPopup(
-							StackablePopupOpen::FileTree(
-								FileTreeOpen::new(commit),
-							),
-						));
-					}
-				} else if key_match(
-					e,
-					self.key_config.keys.focus_left,
-				) {
 					self.hide_stacked(false);
 				}
 
@@ -234,6 +210,7 @@ impl InspectCommitComponent {
 		sender: &Sender<AsyncGitNotification>,
 		theme: SharedTheme,
 		key_config: SharedKeyConfig,
+		options: SharedOptions,
 	) -> Self {
 		Self {
 			queue: queue.clone(),
@@ -255,6 +232,7 @@ impl InspectCommitComponent {
 			git_diff: AsyncDiff::new(repo.borrow().clone(), sender),
 			visible: false,
 			key_config,
+			options,
 		}
 	}
 
@@ -298,7 +276,7 @@ impl InspectCommitComponent {
 						diff_type: DiffType::Commit(
 							request.commit_id,
 						),
-						options: DiffOptions::default(),
+						options: self.options.borrow().diff_options(),
 					};
 
 					if let Some((params, last)) =
