@@ -7,6 +7,7 @@ use crate::{
 	keys::{key_match, SharedKeyConfig},
 	queue::{InternalEvent, Queue, StackablePopupOpen},
 	strings::{self, order, symbol},
+	try_or_popup,
 	ui::{self, common_nav, style::SharedTheme},
 	AsyncAppNotification, AsyncNotification,
 };
@@ -21,19 +22,19 @@ use asyncgit::{
 use crossbeam_channel::Sender;
 use crossterm::event::Event;
 use filetreelist::{FileTree, FileTreeItem};
-use std::{borrow::Cow, fmt::Write};
-use std::{
-	collections::BTreeSet,
-	convert::From,
-	path::{Path, PathBuf},
-};
-use tui::{
+use ratatui::{
 	backend::Backend,
 	layout::{Constraint, Direction, Layout, Rect},
 	text::Span,
 	widgets::{Block, Borders},
 	Frame,
 };
+use std::{borrow::Cow, fmt::Write};
+use std::{
+	collections::BTreeSet,
+	convert::From,
+	path::{Path, PathBuf},
+};
 use unicode_truncate::UnicodeTruncateStr;
 use unicode_width::UnicodeWidthStr;
 
@@ -199,11 +200,7 @@ impl RevisionFilesComponent {
 			width.saturating_sub(indent_str.len() + path_arrow.len());
 
 		let path = format!(
-			"{}{}{:w$}",
-			indent_str,
-			path_arrow,
-			path,
-			w = available_width
+			"{indent_str}{path_arrow}{path:available_width$}"
 		);
 
 		Span::styled(path, theme.file_tree_item(is_path, selected))
@@ -285,7 +282,11 @@ impl RevisionFilesComponent {
 		}
 	}
 
-	fn draw_tree<B: Backend>(&self, f: &mut Frame<B>, area: Rect) {
+	fn draw_tree<B: Backend>(
+		&self,
+		f: &mut Frame<B>,
+		area: Rect,
+	) -> Result<()> {
 		let tree_height = usize::from(area.height.saturating_sub(2));
 		let tree_width = usize::from(area.width);
 
@@ -316,7 +317,7 @@ impl RevisionFilesComponent {
 
 		let is_tree_focused = matches!(self.focus, Focus::Tree);
 
-		let title = self.title_within(tree_width);
+		let title = self.title_within(tree_width)?;
 		let block = Block::default()
 			.title(Span::styled(
 				title,
@@ -345,12 +346,15 @@ impl RevisionFilesComponent {
 		if is_tree_focused {
 			self.scroll.draw(f, area, &self.theme);
 		}
+
+		Ok(())
 	}
 
-	fn title_within(&self, tree_width: usize) -> String {
+	fn title_within(&self, tree_width: usize) -> Result<String> {
 		let mut title = String::from("Files at");
 		let message = self.revision.as_ref().and_then(|c| {
-			let _ = write!(title, " {{{}}}", c.id.get_short_string());
+			let _ignore =
+				write!(title, " {{{}}}", c.id.get_short_string());
 
 			c.message.lines().next()
 		});
@@ -365,20 +369,20 @@ impl RevisionFilesComponent {
 				);
 
 			if message.width() <= available {
-				let _ = write!(title, " [{message}]");
+				write!(title, " [{message}]")?;
 			} else if available > 1 {
-				let _ = write!(
+				write!(
 					title,
 					" [{}{}]",
 					message.unicode_truncate(available - 1).0,
 					ELLIPSIS
-				);
+				)?;
 			} else {
 				title.push(ELLIPSIS);
 			}
 		}
 
-		title
+		Ok(title)
 	}
 
 	fn request_files(&mut self, commit: CommitId) {
@@ -407,7 +411,7 @@ impl DrawableComponent for RevisionFilesComponent {
 				)
 				.split(area);
 
-			self.draw_tree(f, chunks[0]);
+			self.draw_tree(f, chunks[0])?;
 
 			self.current_file.draw(f, chunks[1])?;
 		}
@@ -451,6 +455,14 @@ impl Component for RevisionFilesComponent {
 				)
 				.order(order::RARE_ACTION),
 			);
+			out.push(
+				CommandInfo::new(
+					strings::commands::copy_path(&self.key_config),
+					self.tree.selected_file().is_some(),
+					true,
+				)
+				.order(order::RARE_ACTION),
+			);
 			tree_nav_cmds(&self.tree, &self.key_config, out);
 		} else {
 			self.current_file.commands(out, force_all);
@@ -519,6 +531,15 @@ impl Component for RevisionFilesComponent {
 					);
 					return Ok(EventState::Consumed);
 				}
+			} else if key_match(key, self.key_config.keys.copy) {
+				if let Some(file) = self.selected_file_path() {
+					try_or_popup!(
+						self,
+						strings::POPUP_FAIL_COPY,
+						crate::clipboard::copy_string(&file)
+					);
+				}
+				return Ok(EventState::Consumed);
 			} else if !is_tree_focused {
 				return self.current_file.event(event);
 			}
