@@ -13,15 +13,15 @@ use crate::{
 use anyhow::Result;
 use crossterm::event::{Event, KeyCode, KeyModifiers};
 use itertools::Itertools;
-use std::{cell::Cell, collections::HashMap, ops::Range};
-use tui::{
+use ratatui::{
 	backend::Backend,
 	layout::{Alignment, Rect},
 	style::Modifier,
-	text::{Spans, Text},
+	text::{Line, Text},
 	widgets::{Clear, Paragraph},
 	Frame,
 };
+use std::{cell::Cell, collections::HashMap, ops::Range};
 
 #[derive(PartialEq, Eq)]
 pub enum InputType {
@@ -237,7 +237,7 @@ impl TextInputComponent {
 				Text::styled(text_before_cursor, style),
 			);
 			if ends_in_nl {
-				txt.lines.push(Spans::default());
+				txt.lines.push(Line::default());
 			}
 		}
 
@@ -251,7 +251,7 @@ impl TextInputComponent {
 
 		let cursor_highlighting = {
 			let mut h = HashMap::with_capacity(2);
-			h.insert("\n", "\u{21b5}\n\r");
+			h.insert("\n", "\u{21b5}\r\n\n");
 			h.insert(" ", symbol::WHITESPACE);
 			h
 		};
@@ -330,7 +330,7 @@ fn text_append<'a>(txt: Text<'a>, append: Text<'a>) -> Text<'a> {
 	let mut txt = txt;
 	if let Some(last_line) = txt.lines.last_mut() {
 		if let Some(first_line) = append.lines.first() {
-			last_line.0.extend(first_line.0.clone());
+			last_line.spans.extend(first_line.spans.clone());
 		}
 
 		if append.lines.len() > 1 {
@@ -523,7 +523,7 @@ impl Component for TextInputComponent {
 #[cfg(test)]
 mod tests {
 	use super::*;
-	use tui::{style::Style, text::Span};
+	use ratatui::{style::Style, text::Span};
 
 	#[test]
 	fn test_smoke() {
@@ -564,9 +564,12 @@ mod tests {
 
 		let txt = comp.get_draw_text();
 
-		assert_eq!(txt.lines[0].0.len(), 1);
-		assert_eq!(get_text(&txt.lines[0].0[0]), Some("a"));
-		assert_eq!(get_style(&txt.lines[0].0[0]), Some(&underlined));
+		assert_eq!(txt.lines[0].spans.len(), 1);
+		assert_eq!(get_text(&txt.lines[0].spans[0]), Some("a"));
+		assert_eq!(
+			get_style(&txt.lines[0].spans[0]),
+			Some(&underlined)
+		);
 	}
 
 	#[test]
@@ -590,18 +593,18 @@ mod tests {
 
 		let txt = comp.get_draw_text();
 
-		assert_eq!(txt.lines[0].0.len(), 2);
-		assert_eq!(get_text(&txt.lines[0].0[0]), Some("a"));
+		assert_eq!(txt.lines[0].spans.len(), 2);
+		assert_eq!(get_text(&txt.lines[0].spans[0]), Some("a"));
 		assert_eq!(
-			get_style(&txt.lines[0].0[0]),
+			get_style(&txt.lines[0].spans[0]),
 			Some(&not_underlined)
 		);
 		assert_eq!(
-			get_text(&txt.lines[0].0[1]),
+			get_text(&txt.lines[0].spans[1]),
 			Some(symbol::WHITESPACE)
 		);
 		assert_eq!(
-			get_style(&txt.lines[0].0[1]),
+			get_style(&txt.lines[0].spans[1]),
 			Some(&underlined_whitespace)
 		);
 	}
@@ -627,13 +630,19 @@ mod tests {
 		let txt = comp.get_draw_text();
 
 		assert_eq!(txt.lines.len(), 2);
-		assert_eq!(txt.lines[0].0.len(), 2);
-		assert_eq!(txt.lines[1].0.len(), 2);
-		assert_eq!(get_text(&txt.lines[0].0[0]), Some("a"));
-		assert_eq!(get_text(&txt.lines[0].0[1]), Some("\u{21b5}"));
-		assert_eq!(get_style(&txt.lines[0].0[1]), Some(&underlined));
-		assert_eq!(get_text(&txt.lines[1].0[0]), Some(""));
-		assert_eq!(get_text(&txt.lines[1].0[1]), Some("b"));
+		assert_eq!(txt.lines[0].spans.len(), 2);
+		assert_eq!(txt.lines[1].spans.len(), 2);
+		assert_eq!(get_text(&txt.lines[0].spans[0]), Some("a"));
+		assert_eq!(
+			get_text(&txt.lines[0].spans[1]),
+			Some("\u{21b5}")
+		);
+		assert_eq!(
+			get_style(&txt.lines[0].spans[1]),
+			Some(&underlined)
+		);
+		assert_eq!(get_text(&txt.lines[1].spans[0]), Some(""));
+		assert_eq!(get_text(&txt.lines[1].spans[1]), Some("b"));
 	}
 
 	#[test]
@@ -656,12 +665,15 @@ mod tests {
 		let txt = comp.get_draw_text();
 
 		assert_eq!(txt.lines.len(), 2);
-		assert_eq!(txt.lines[0].0.len(), 2);
-		assert_eq!(txt.lines[1].0.len(), 1);
-		assert_eq!(get_text(&txt.lines[0].0[0]), Some("a"));
-		assert_eq!(get_text(&txt.lines[0].0[1]), Some(""));
-		assert_eq!(get_style(&txt.lines[0].0[0]), Some(&underlined));
-		assert_eq!(get_text(&txt.lines[1].0[0]), Some("b"));
+		assert_eq!(txt.lines[0].spans.len(), 2);
+		assert_eq!(txt.lines[1].spans.len(), 1);
+		assert_eq!(get_text(&txt.lines[0].spans[0]), Some("a"));
+		assert_eq!(get_text(&txt.lines[0].spans[1]), Some(""));
+		assert_eq!(
+			get_style(&txt.lines[0].spans[0]),
+			Some(&underlined)
+		);
+		assert_eq!(get_text(&txt.lines[1].spans[0]), Some("b"));
 	}
 
 	#[test]
