@@ -104,6 +104,9 @@ pub fn msg_title_info(_key_config: &SharedKeyConfig) -> String {
 pub fn commit_title() -> String {
 	"Commit".to_string()
 }
+pub fn commit_reword_title() -> String {
+	"Reword Commit".to_string()
+}
 
 pub fn commit_title_merge() -> String {
 	"Commit (Merge)".to_string()
@@ -193,8 +196,7 @@ pub fn confirm_msg_reset() -> String {
 }
 pub fn confirm_msg_reset_lines(lines: usize) -> String {
 	format!(
-		"are you sure you want to discard {} selected lines?",
-		lines
+		"are you sure you want to discard {lines} selected lines?"
 	)
 }
 pub fn confirm_msg_stashdrop(
@@ -273,8 +275,7 @@ pub fn confirm_msg_force_push(
 	branch_ref: &str,
 ) -> String {
 	format!(
-        "Confirm force push to branch '{}' ?  This may rewrite history.",
-        branch_ref
+        "Confirm force push to branch '{branch_ref}' ?  This may rewrite history."
     )
 }
 pub fn log_title(_key_config: &SharedKeyConfig) -> String {
@@ -285,10 +286,7 @@ pub fn file_log_title(
 	selected: usize,
 	revisions: usize,
 ) -> String {
-	format!(
-		"Revisions of '{}' ({}/{})",
-		file_path, selected, revisions
-	)
+	format!("Revisions of '{file_path}' ({selected}/{revisions})")
 }
 pub fn blame_title(_key_config: &SharedKeyConfig) -> String {
 	"Blame".to_string()
@@ -426,7 +424,7 @@ pub mod commands {
 	static CMD_GROUP_GENERAL: &str = "-- General --";
 	static CMD_GROUP_DIFF: &str = "-- Diff --";
 	static CMD_GROUP_CHANGES: &str = "-- Changes --";
-	static CMD_GROUP_COMMIT: &str = "-- Commit --";
+	static CMD_GROUP_COMMIT_POPUP: &str = "-- Commit Popup --";
 	static CMD_GROUP_STASHING: &str = "-- Stashing --";
 	static CMD_GROUP_STASHES: &str = "-- Stashes --";
 	static CMD_GROUP_LOG: &str = "-- Log --";
@@ -452,6 +450,16 @@ pub mod commands {
 			CMD_GROUP_GENERAL,
 		)
 	}
+	pub fn find_branch(key_config: &SharedKeyConfig) -> CommandText {
+		CommandText::new(
+			format!(
+				"Find [{}]",
+				key_config.get_hint(key_config.keys.branch_find)
+			),
+			"find branch in list",
+			CMD_GROUP_GENERAL,
+		)
+	}
 	pub fn toggle_tabs_direct(
 		key_config: &SharedKeyConfig,
 	) -> CommandText {
@@ -522,8 +530,8 @@ pub mod commands {
 		CommandText::new(
 			format!(
 				"Scroll [{}{}]",
-				key_config.get_hint(key_config.keys.focus_above),
-				key_config.get_hint(key_config.keys.focus_below)
+				key_config.get_hint(key_config.keys.move_up),
+				key_config.get_hint(key_config.keys.move_down)
 			),
 			"scroll up or down in focused view",
 			CMD_GROUP_GENERAL,
@@ -563,6 +571,16 @@ pub mod commands {
 			CMD_GROUP_LOG,
 		)
 	}
+	pub fn copy_path(key_config: &SharedKeyConfig) -> CommandText {
+		CommandText::new(
+			format!(
+				"Copy Path [{}]",
+				key_config.get_hint(key_config.keys.copy),
+			),
+			"copy selected file path to clipboard",
+			CMD_GROUP_LOG,
+		)
+	}
 	pub fn push_tags(key_config: &SharedKeyConfig) -> CommandText {
 		CommandText::new(
 			format!(
@@ -675,6 +693,19 @@ pub mod commands {
 			CMD_GROUP_DIFF,
 		)
 	}
+	pub fn close_fuzzy_finder(
+		key_config: &SharedKeyConfig,
+	) -> CommandText {
+		CommandText::new(
+			format!(
+				"Close [{}{}]",
+				key_config.get_hint(key_config.keys.exit_popup),
+				key_config.get_hint(key_config.keys.enter),
+			),
+			"close fuzzy finder",
+			CMD_GROUP_GENERAL,
+		)
+	}
 	pub fn close_popup(key_config: &SharedKeyConfig) -> CommandText {
 		CommandText::new(
 			format!(
@@ -685,6 +716,17 @@ pub mod commands {
 			CMD_GROUP_GENERAL,
 		)
 	}
+	pub fn scroll_popup(key_config: &SharedKeyConfig) -> CommandText {
+		CommandText::new(
+			format!(
+				"Scroll [{}{}]",
+				key_config.get_hint(key_config.keys.popup_down),
+				key_config.get_hint(key_config.keys.popup_up),
+			),
+			"scroll up or down in popup",
+			CMD_GROUP_GENERAL,
+		)
+	}
 	pub fn close_msg(key_config: &SharedKeyConfig) -> CommandText {
 		CommandText::new(
 			format!(
@@ -848,7 +890,7 @@ pub mod commands {
 				key_config.get_hint(key_config.keys.open_commit),
 			),
 			"open commit popup (available in non-empty stage)",
-			CMD_GROUP_COMMIT,
+			CMD_GROUP_GENERAL,
 		)
 	}
 	pub fn commit_open_editor(
@@ -861,7 +903,7 @@ pub mod commands {
 					.get_hint(key_config.keys.open_commit_editor),
 			),
 			"open commit editor (available in commit popup)",
-			CMD_GROUP_COMMIT,
+			CMD_GROUP_COMMIT_POPUP,
 		)
 	}
 	pub fn commit_next_msg_from_history(
@@ -874,7 +916,7 @@ pub mod commands {
 					.get_hint(key_config.keys.commit_history_next),
 			),
 			"use previous commit message from history",
-			CMD_GROUP_COMMIT,
+			CMD_GROUP_COMMIT_POPUP,
 		)
 	}
 	pub fn commit_enter(key_config: &SharedKeyConfig) -> CommandText {
@@ -884,10 +926,26 @@ pub mod commands {
 				key_config.get_hint(key_config.keys.enter),
 			),
 			"commit (available when commit message is non-empty)",
-			CMD_GROUP_COMMIT,
+			CMD_GROUP_COMMIT_POPUP,
 		)
 		.hide_help()
 	}
+	pub fn toggle_verify(
+		key_config: &SharedKeyConfig,
+		current_verify: bool,
+	) -> CommandText {
+		let verb = if current_verify { "disable" } else { "enable" };
+		CommandText::new(
+			format!(
+				"{} hooks [{}]",
+				verb,
+				key_config.get_hint(key_config.keys.toggle_verify),
+			),
+			"toggle running on commit hooks (available in commit popup)",
+			CMD_GROUP_COMMIT_POPUP,
+		)
+	}
+
 	pub fn commit_amend(key_config: &SharedKeyConfig) -> CommandText {
 		CommandText::new(
 			format!(
@@ -895,7 +953,7 @@ pub mod commands {
 				key_config.get_hint(key_config.keys.commit_amend),
 			),
 			"amend last commit (available in commit popup)",
-			CMD_GROUP_COMMIT,
+			CMD_GROUP_COMMIT_POPUP,
 		)
 	}
 	pub fn edit_item(key_config: &SharedKeyConfig) -> CommandText {
@@ -979,7 +1037,7 @@ pub mod commands {
 		CommandText::new(
 			format!(
 				"Back [{}]",
-				key_config.get_hint(key_config.keys.focus_left),
+				key_config.get_hint(key_config.keys.move_left),
 			),
 			"view and select changed files",
 			CMD_GROUP_GENERAL,
@@ -991,7 +1049,7 @@ pub mod commands {
 		CommandText::new(
 			format!(
 				"Diff [{}]",
-				key_config.get_hint(key_config.keys.focus_right),
+				key_config.get_hint(key_config.keys.move_right),
 			),
 			"inspect file diff",
 			CMD_GROUP_GENERAL,
@@ -1118,7 +1176,7 @@ pub mod commands {
 		CommandText::new(
 			format!(
 				"Inspect [{}]",
-				key_config.get_hint(key_config.keys.focus_right),
+				key_config.get_hint(key_config.keys.stash_open),
 			),
 			"open stash commit details (allows to diff files)",
 			CMD_GROUP_STASHES,
@@ -1143,7 +1201,7 @@ pub mod commands {
 		CommandText::new(
 			format!(
 				"Inspect [{}]",
-				key_config.get_hint(key_config.keys.focus_right),
+				key_config.get_hint(key_config.keys.move_right),
 			),
 			"inspect selected commit in detail",
 			CMD_GROUP_GENERAL,
@@ -1184,6 +1242,19 @@ pub mod commands {
 			CMD_GROUP_LOG,
 		)
 	}
+	pub fn log_checkout_commit(
+		key_config: &SharedKeyConfig,
+	) -> CommandText {
+		CommandText::new(
+			format!(
+				"Checkout [{}]",
+				key_config
+					.get_hint(key_config.keys.log_checkout_commit),
+			),
+			"checkout commit",
+			CMD_GROUP_LOG,
+		)
+	}
 	pub fn inspect_file_tree(
 		key_config: &SharedKeyConfig,
 	) -> CommandText {
@@ -1209,6 +1280,51 @@ pub mod commands {
 			CMD_GROUP_LOG,
 		)
 	}
+	pub fn log_reset_commit(
+		key_config: &SharedKeyConfig,
+	) -> CommandText {
+		CommandText::new(
+			format!(
+				"Reset [{}]",
+				key_config.get_hint(key_config.keys.log_reset_comit),
+			),
+			"reset to commit",
+			CMD_GROUP_LOG,
+		)
+	}
+	pub fn log_reword_commit(
+		key_config: &SharedKeyConfig,
+	) -> CommandText {
+		CommandText::new(
+			format!(
+				"Reword [{}]",
+				key_config.get_hint(key_config.keys.log_reword_comit),
+			),
+			"reword commit message",
+			CMD_GROUP_LOG,
+		)
+	}
+	pub fn reset_commit(key_config: &SharedKeyConfig) -> CommandText {
+		CommandText::new(
+			format!(
+				"Confirm  [{}]",
+				key_config.get_hint(key_config.keys.enter),
+			),
+			"confirm reset",
+			CMD_GROUP_LOG,
+		)
+	}
+	pub fn reset_type(key_config: &SharedKeyConfig) -> CommandText {
+		CommandText::new(
+			format!(
+				"Change Type  [{}{}]",
+				key_config.get_hint(key_config.keys.move_up),
+				key_config.get_hint(key_config.keys.move_down)
+			),
+			"change reset type",
+			CMD_GROUP_LOG,
+		)
+	}
 	pub fn tag_commit_confirm_msg(
 		key_config: &SharedKeyConfig,
 	) -> CommandText {
@@ -1445,6 +1561,17 @@ pub mod commands {
 			CMD_GROUP_GENERAL,
 		)
 	}
+
+	pub fn status_fetch(key_config: &SharedKeyConfig) -> CommandText {
+		CommandText::new(
+			format!(
+				"Fetch [{}]",
+				key_config.get_hint(key_config.keys.fetch),
+			),
+			"fetch",
+			CMD_GROUP_GENERAL,
+		)
+	}
 	pub fn status_pull(key_config: &SharedKeyConfig) -> CommandText {
 		CommandText::new(
 			format!(
@@ -1462,7 +1589,7 @@ pub mod commands {
 		CommandText::new(
 			format!(
 				"Fetch [{}]",
-				key_config.get_hint(key_config.keys.pull),
+				key_config.get_hint(key_config.keys.fetch),
 			),
 			"fetch/prune",
 			CMD_GROUP_BRANCHES,
