@@ -32,6 +32,7 @@ impl StashList {
 		Self {
 			visible: false,
 			list: CommitList::new(
+				repo.clone(),
 				&strings::stashlist_title(&key_config),
 				theme,
 				queue.clone(),
@@ -147,10 +148,10 @@ impl StashList {
 }
 
 impl DrawableComponent for StashList {
-	fn draw<B: tui::backend::Backend>(
+	fn draw<B: ratatui::backend::Backend>(
 		&self,
-		f: &mut tui::Frame<B>,
-		rect: tui::layout::Rect,
+		f: &mut ratatui::Frame<B>,
+		rect: ratatui::layout::Rect,
 	) -> Result<()> {
 		self.list.draw(f, rect)?;
 
