@@ -21,17 +21,17 @@ use asyncgit::{
 	},
 	sync::{BranchCompare, CommitId},
 	AsyncBranchesJob, AsyncDiff, AsyncGitNotification, AsyncStatus,
-	DiffParams, DiffType, PushType, StatusParams,
+	DiffParams, DiffType, PushType, StatusItem, StatusParams,
 };
 use crossbeam_channel::Sender;
 use crossterm::event::Event;
 use itertools::Itertools;
-use std::convert::Into;
-use tui::{
+use ratatui::{
 	layout::{Alignment, Constraint, Direction, Layout},
 	style::{Color, Style},
 	widgets::{Block, BorderType, Borders, Paragraph},
 };
+use std::convert::Into;
 
 /// what part of the screen is focused
 #[derive(PartialEq)]
@@ -82,10 +82,10 @@ pub struct Status {
 }
 
 impl DrawableComponent for Status {
-	fn draw<B: tui::backend::Backend>(
+	fn draw<B: ratatui::backend::Backend>(
 		&self,
-		f: &mut tui::Frame<B>,
-		rect: tui::layout::Rect,
+		f: &mut ratatui::Frame<B>,
+		rect: ratatui::layout::Rect,
 	) -> Result<()> {
 		let repo_unclean = self.repo_state_unclean();
 		let rects = if repo_unclean {
@@ -97,7 +97,7 @@ impl DrawableComponent for Status {
 				)
 				.split(rect)
 		} else {
-			vec![rect]
+			std::rc::Rc::new([rect])
 		};
 
 		let chunks = Layout::default()
@@ -105,8 +105,8 @@ impl DrawableComponent for Status {
 			.constraints(
 				if self.focus == Focus::Diff {
 					[
-						Constraint::Percentage(30),
-						Constraint::Percentage(70),
+						Constraint::Percentage(0),
+						Constraint::Percentage(100),
 					]
 				} else {
 					[
@@ -215,10 +215,10 @@ impl Status {
 		}
 	}
 
-	fn draw_branch_state<B: tui::backend::Backend>(
+	fn draw_branch_state<B: ratatui::backend::Backend>(
 		&self,
-		f: &mut tui::Frame<B>,
-		chunks: &[tui::layout::Rect],
+		f: &mut ratatui::Frame<B>,
+		chunks: &[ratatui::layout::Rect],
 	) {
 		if let Some(branch_name) = self.git_branch_name.last() {
 			let ahead_behind = self
@@ -232,8 +232,7 @@ impl Status {
 				});
 
 			let w = Paragraph::new(format!(
-				"{}{{{}}}",
-				ahead_behind, branch_name
+				"{ahead_behind}{{{branch_name}}}"
 			))
 			.alignment(Alignment::Right);
 
@@ -297,10 +296,10 @@ impl Status {
 		}
 	}
 
-	fn draw_repo_state<B: tui::backend::Backend>(
+	fn draw_repo_state<B: ratatui::backend::Backend>(
 		&self,
-		f: &mut tui::Frame<B>,
-		r: tui::layout::Rect,
+		f: &mut ratatui::Frame<B>,
+		r: ratatui::layout::Rect,
 	) {
 		if self.git_state != RepoState::Clean {
 			let txt = Self::repo_state_text(
@@ -465,6 +464,10 @@ impl Status {
 		Ok(())
 	}
 
+	pub fn get_files_changes(&mut self) -> Result<Vec<StatusItem>> {
+		Ok(self.git_status_stage.last()?.items)
+	}
+
 	fn update_status(&mut self) -> Result<()> {
 		let stage_status = self.git_status_stage.last()?;
 		self.index.set_items(&stage_status.items)?;
@@ -556,8 +559,7 @@ impl Status {
 			item.path.as_str(),
 		) {
 			self.queue.push(InternalEvent::ShowErrorMsg(format!(
-				"reset failed:\n{}",
-				e
+				"reset failed:\n{e}"
 			)));
 
 			false
@@ -592,6 +594,12 @@ impl Status {
 		}
 	}
 
+	fn fetch(&self) {
+		if self.can_pull() {
+			self.queue.push(InternalEvent::FetchRemotes);
+		}
+	}
+
 	fn pull(&self) {
 		if let Some(branch) = self.git_branch_name.last() {
 			self.queue.push(InternalEvent::Pull(branch));
@@ -672,7 +680,7 @@ impl Status {
 		let focus_on_diff = self.is_focus_on_diff();
 		out.push(
 			CommandInfo::new(
-				strings::commands::diff_focus_left(&self.key_config),
+				strings::commands::close_popup(&self.key_config),
 				true,
 				(self.visible && focus_on_diff) || force_all,
 			)
@@ -759,6 +767,12 @@ impl Component for Status {
 				true,
 				self.can_push() && !focus_on_diff,
 			));
+
+			out.push(CommandInfo::new(
+				strings::commands::status_fetch(&self.key_config),
+				self.can_pull(),
+				!focus_on_diff,
+			));
 			out.push(CommandInfo::new(
 				strings::commands::status_pull(&self.key_config),
 				self.can_pull(),
@@ -803,19 +817,7 @@ impl Component for Status {
 			));
 		}
 
-		{
-			out.push(CommandInfo::new(
-				strings::commands::edit_item(&self.key_config),
-				if focus_on_diff {
-					true
-				} else {
-					self.can_focus_diff()
-				},
-				self.visible || force_all,
-			));
-
-			self.commands_nav(out, force_all);
-		}
+		self.commands_nav(out, force_all);
 
 		visibility_blocking(self)
 	}
@@ -834,19 +836,7 @@ impl Component for Status {
 			}
 
 			if let Event::Key(k) = ev {
-				return if key_match(k, self.key_config.keys.edit_file)
-					&& (self.can_focus_diff()
-						|| self.is_focus_on_diff())
-				{
-					if let Some((path, _)) = self.selected_path() {
-						self.queue.push(
-							InternalEvent::OpenExternalEditor(Some(
-								path,
-							)),
-						);
-					}
-					Ok(EventState::Consumed)
-				} else if key_match(
+				return if key_match(
 					k,
 					self.key_config.keys.open_commit,
 				) && self.can_commit()
@@ -862,13 +852,13 @@ impl Component for Status {
 						.map(Into::into)
 				} else if key_match(
 					k,
-					self.key_config.keys.focus_right,
+					self.key_config.keys.move_right,
 				) && self.can_focus_diff()
 				{
 					self.switch_focus(Focus::Diff).map(Into::into)
 				} else if key_match(
 					k,
-					self.key_config.keys.focus_left,
+					self.key_config.keys.exit_popup,
 				) {
 					self.switch_focus(match self.diff_target {
 						DiffTarget::Stage => Focus::Stage,
@@ -905,6 +895,12 @@ impl Component for Status {
 				{
 					self.push(false);
 					Ok(EventState::Consumed)
+				} else if key_match(k, self.key_config.keys.fetch)
+					&& !self.is_focus_on_diff()
+					&& self.can_pull()
+				{
+					self.fetch();
+					Ok(EventState::Consumed)
 				} else if key_match(k, self.key_config.keys.pull)
 					&& !self.is_focus_on_diff()
 					&& self.can_pull()
